type Environment = 'development' | 'testing' | 'production';
interface Domain {
  apiDomain: string;
  walnutcupDomain: string;
  stpageplayerDomain: string;
  contestIdeDomain: string;
  contestHost: string;
  contestDomain: string;
}
type AllDomain = {
  [key in Environment]: Domain;
};

export function extractUrlValue(key: string, url?: string) {
  if (typeof url === 'undefined') url = window.location.search;
  const match = url.match('[?&]' + key + '=([^&]+)');
  return match ? match[1] : null;
}

export function getEnvironment(): Environment {
  if (process.env.NODE_ENV === 'development') {
    return 'development';
  }

  const debugEnv = extractUrlValue('debugenv');
  if (debugEnv) {
    return debugEnv as Environment;
  }

  const hostname = window.location.hostname;

  if (hostname.indexOf('testing') >= 0 || hostname.indexOf('huodong') >= 0) {
    return 'testing';
  }

  return 'production';
}

const allDomain: AllDomain = {
  development: {
    apiDomain: '',
    walnutcupDomain: `https://walnutcup.testing11.hetao101.com`,
    stpageplayerDomain: `https://stpageplayer.testing11.hetaobiancheng.com`,
    contestIdeDomain: `https://contestide.testing11.hetao101.com`,
    contestHost: `contest.testing11.hetao101.com`,
    contestDomain: `https://contest.testing11.hetao101.com`,
  },
  testing: {
    apiDomain: 'https://contest.testing11.hetao101.com',
    walnutcupDomain: `https://walnutcup.testing11.hetao101.com`,
    stpageplayerDomain: `https://stpageplayer.testing11.hetaobiancheng.com`,
    contestIdeDomain: `https://contestide.testing11.hetao101.com`,
    contestHost: `contest.testing11.hetao101.com`,
    contestDomain: `https://contest.testing11.hetao101.com`,
  },
  production: {
    apiDomain: 'https://contest.hetao101.com',
    walnutcupDomain: `https://walnutcup.hetao101.com`,
    stpageplayerDomain: `https://stpageplayer.hetaobiancheng.com`,
    contestIdeDomain: `https://contestide.hetao101.com`,
    contestHost: `contest.hetao101.com`,
    contestDomain: `https://contest.hetao101.com`,
  },
};

export const environment = getEnvironment();

export const domains = allDomain[environment];

export const tagName = extractUrlValue('tag') || '-1';

function getContestName() {
  const contestNameMatch = window.location.pathname.match(/[^/]+/);
  return contestNameMatch ? contestNameMatch[0] : '';
}

export const contestName = getContestName();
