"use strict";
const Generator = require("yeoman-generator");
const chalk = require("chalk");
const yosay = require("yosay");
const fs = require("fs");
const boxen = require("boxen");

module.exports = class extends Generator {
  constructor(args, opts) {
    super(args, opts);

    this.argument("appName", { type: String, required: true });

    const projectDir = this.destinationPath(this.options.appName);

    if (fs.existsSync(projectDir)) {
      if (fs.readdirSync(projectDir).length > 0) {
        throw new Error(`${this.options.appName}文件夹已经存在，并且非空`);
      }
    }

    this.destinationRoot(this.options.appName);
  }

  initializing() {
    this.log(chalk.greenBright("stage initializing"));
  }

  prompting() {
    // Have Yeoman greet the user.
    this.log(
      yosay(`Welcome to the rad ${chalk.red("generator-kaokei")} generator!`)
    );

    // const prompts = [
    //   {
    //     type: "confirm",
    //     name: "someAnswer",
    //     message: "Would you like to enable this option?",
    //     default: true
    //   }
    // ];

    // return this.prompt(prompts).then(props => {
    //   // To access props later use this.props.someAnswer;
    //   this.props = props;
    // });
  }

  configuring() {
    this.log(chalk.greenBright("stage configuring"));
  }

  default() {
    this.log(chalk.greenBright("stage default"));
  }

  writing() {
    this.log(chalk.greenBright("stage writing"));

    const tplFiles = ["README.md", "package.json"];

    this.fs.copy(this.templatePath("**/*"), this.destinationRoot(), {
      globOptions: { dot: true, ignore: tplFiles }
    });

    tplFiles.forEach(file => {
      this.fs.copyTpl(this.templatePath(file), this.destinationPath(file), {
        appName: this.options.appName
      });
    });
  }

  conflicts() {
    this.log(chalk.greenBright("stage conflicts"));
  }

  install() {
    this.log(chalk.greenBright("stage install"));

    this.spawnCommandSync("git", ["init", "--quiet"]);

    this.installDependencies({
      npm: true,
      bower: false,
      yarn: false,
      skipMessage: true
    });
  }

  end() {
    this.log(chalk.greenBright("stage end"));

    this.spawnCommandSync("git", ["add", "-A"]);
    this.spawnCommandSync("git", [
      "commit",
      "-m",
      "init project",
      "--quiet",
      "--no-verify"
    ]);

    this.log(boxen(chalk.blue(`cd ${this.options.appName}`), { padding: 1 }));
  }

  method1() {
    this.log("method 1 just ran");
  }

  method2() {
    this.log("method 2 just ran");
  }
};
